<# 
.SYNOPSIS
    Create a site administrator and enable remote administration (along with necessary SSL cert)
 
.DESCRIPTION 
    Create a site administrator and enable remote administration (along with necessary SSL cert)

    TODO: separate remote administration and cert creation into separate scripts, or make them optional

#>

param(
	[Parameter(Mandatory=$False)][string]$serverName = "localhost",
	[Parameter(Mandatory=$False)][int]$eftAdminPort = 1100,
	[Parameter(Mandatory=$False)][string]$eftAdminName = "admin",
	[Parameter(Mandatory=$False)][string]$eftAdminPassword = "myAdmin123",
	[Parameter(Mandatory=$False)][string]$siteName = "MySite",
	[Parameter(Mandatory=$False)][string]$StaticFolderPath = "\\gsbstorageacct.file.core.windows.net\gsbshared15\Config_Static",
	[Parameter(Mandatory=$False)][string]$AdminCertPassphrase = "passphrase",
	[Parameter(Mandatory=$False)][string]$siteAdminName = "siteAdmin"
)


#------------------------------------------------------------
# login as admin
#------------------------------------------------------------

try {
    $server = New-Object -ComObject 'SFTPComInterface.CIServer'
    $server.Connect( $serverName, $eftAdminPort, $eftAdminName, $eftAdminPassword );
    Write-Host "connected"
}
catch {
    $errorMessage = $_.Exception.Message;
    Write-Host "failed to connect to server ${serverName}: ${errorMessage}"
    Exit;
}

#------------------------------------------------------------
# create site admin
#------------------------------------------------------------

try {
 
    $adminAccountType = 0 # EFTAccount, LocalComputerAcount, ADAccount
    $bGroup = $False

	Write-Output "calling CreateAdmin"
    $adminAcct = $server.CreateAdmin($siteAdminName, $siteAdminPassword, $adminAccountType, $bGroup)
	Write-Output "done: CreateAdmin"

    $perm = 1 # SiteManagement

	Write-Output "setting SiteName and perimissions"
    $adminPerm = New-Object -ComObject 'SFTPComInterface.CIAdminPermission'
    $adminPerm.SiteName = $siteName
    $adminPerm.Permission = $perm
    $adminAcct.AddPermission($adminPerm)
	Write-Output "done: setting SiteName and perimissions"
}
catch [Exception] {
	$errorStr = $_.Exception|format-list -force
	Write-Host "exception: $errorStr" -ForegroundColor Red
	Exit # given the exception, don't bother to proceed
}

#------------------------------------------------------------
# allow remote admin
#------------------------------------------------------------


$PKPath  = "$StaticFolderPath\AdminSslCert.key"
$CsrPath = "$StaticFolderPath\AdminSslCert.csr"
$CrtPath = "$StaticFolderPath\AdminSslCert.crt"

$CRT = 0
$PEM = 0 #$PKCS12 = 3

try {
	Write-Output "CreateSSLCertificate $PKPath $CsrPath $CrtPath"
	$server.CreateSSLCertificate($PKPath, $CsrPath, $CrtPath, $AdminCertPassphrase, `
                                    "US", "TX", "TEST", "TEST", "7", "TEST", "test@test.com", 1024, 90, $CRT, $PEM, 0, $False, $False)
	Write-Output "done: CreateSSLCertificate"
}
catch [Exception] {
	$errorStr = $_.Exception|format-list -force
	Write-Host "exception: $errorStr" -ForegroundColor Red
    $errorMessage = $_.Exception.Message;
    Write-Host "failed CreateSSLCertificate : ${errorMessage}"
	Exit # given the exception, don't bother to proceed
}


try {
	Write-Output "setting certificates and path names"
    $server.CertificateFilePath = $CrtPath
    $server.KeyFilePath = $PKPath
    $server.PassPhrase = $AdminCertPassphrase
    $server.ApplyChanges()
	Write-Output "done: setting certificates and path names"

	Write-Output "enabling remote administration"
    $bTrue = $True
    $server.AllowRemoteAdministration = $bTrue
    $server.ApplyChanges()
    $server.UseSSLForAdministration = $bTrue
    $server.ApplyChanges()
	Write-Output "done: enabling remote administration"
}
catch [Exception] {
	$errorStr = $_.Exception|format-list -force
	Write-Host "exception: $errorStr" -ForegroundColor Red
}



