##
## Copyright (C) 2018 GlobalSCAPE, Inc.
##
## The copyright to the computer program(s) herein is the property of
## GlobalSCAPE, Inc. The program(s) may be used and/or copied only with
## the written permission of  GlobalSCAPE, Inc. or in accordance with the
## terms and conditions stipulated in the agreement/contract under which
## the program(s) have been supplied.

[CmdletBinding()]
Param(
    [Parameter(Position = 1, Mandatory = $true, HelpMessage = "Enter login")]
    [String] $SiteName = "",

    [Parameter(Position = 2, Mandatory = $true, HelpMessage = "Enter login")]
    [int] $NumTemplates = 10,

    [Parameter(Position = 3, Mandatory = $False, HelpMessage = "Enter a host name or IP address")]
    [String] $EFTAdminHostname = "localhost",

    [Parameter(Position = 4, Mandatory = $False, HelpMessage = "Enter a port where EFT Server is listening for admin connections")]
    [int] [ValidateRange(0, 65535)] $EFTAdminPort = 1100,

    [Parameter(Position = 5, Mandatory = $False, HelpMessage = "Enter a Authentication Type to connect to EFT Server. 0: EFT Login, 1: Windows Login, 2: Network Logon")]
    [int] [ValidateSet(0, 1, 2)]  $EFTAdminAuthType = 1,

    [Parameter(Position = 6, Mandatory = $False, HelpMessage = "Enter login")]
    [String] $EFTAdminUsername,

    [Parameter(Position = 7, Mandatory = $False, HelpMessage = "Enter password")]
    [String] $Password
)

$script:EftServer = $null
$script:EftSites = $null
$script:EftSite = $null
$sw = [Diagnostics.Stopwatch]::StartNew()

$script:EftServer = new-object -ComObject "SFTPCOMInterface.CIServer"

try {
    $script:EftServer.ConnectEx($EFTAdminHostname, $EFTAdminPort, $EFTAdminAuthType, $EFTAdminUsername, $Password)
}
catch [System.Runtime.InteropServices.COMException] {
    Write-host "Exception : $_" -ForegroundColor Red
    exit
}

$script:EftSites = $script:EftServer.Sites()
$sitesCount = $script:EftSites.Count()
$siteFound = $false
for ($j = 0; $j -le $sitesCount - 1; $j++ ) {
    $script:EftSite = $script:EftSites.Item($j)
    if ($Sitename -eq $script:EftSite.Name) {
        $siteFound = $true
        break
    }
}

if (!$siteFound){
    write-host "Site $Sitename Not found"
    exit
}
try {
    $sw.Restart()
    $script:EftServer.AutoSave = $false
}
catch [System.Runtime.InteropServices.COMException] {
    Write-Host "ERROR  ($($sw.ElapsedMilliseconds)ms)" -ForegroundColor red
    Write-host "Exception : $_" -ForegroundColor Red
}

for ($i= 0 ; $i -le $NumTemplates;$i++ ) {
    try{
        $settingsTemplateName = "test_$i"
        Write-Host "Adding '$settingsTemplateName' ... " -NoNewline
        $sw.Restart()
        $script:EftSite.CreateSettingsLevel($settingsTemplateName,"test",$false)
        Write-Host "OK  ($($sw.ElapsedMilliseconds)ms)" -ForegroundColor green
    }
    catch [System.Runtime.InteropServices.COMException] {
        Write-Host "ERROR  ($($sw.ElapsedMilliseconds)ms)" -ForegroundColor red
        Write-host "Exception : $_" -ForegroundColor Red
    }
}
