﻿<#
.SYNOPSIS
   Set the force password reset on initial login property at the server level. This should impact admins.
.DESCRIPTION
   Set the force password reset on initial login property at the server level.  This should impact admins.
.PARAMETER eftAdminPort
   specify the EFT administrative port for COM connection -- default 1100
.PARAMETER eftAdminName
   name of the EFT administrative account
.PARAMETER eftAdminPassword
   password for the EFT administrative account
.PARAMETER auth method
   authentication method - 1 EFT local auth ; 2 Windows Auth

#>

param([int]$eftAdminPort=1100,
      [string]$eftAdminName = "admin",
      [string]$eftAdminPassword = "myAdmin123",
      [int]$authMethod = 1,
      [bool]$bValue = $True
)


#------------------------------------------------------------
# login as admin
#------------------------------------------------------------

try {
    $server = New-Object -ComObject 'SFTPComInterface.CIServer'
    $server.ConnectEx( "localhost", $eftAdminPort, $authMethod, $eftAdminName, $eftAdminPassword );
    Write-Host "connected"
}
catch {
    $errorMessage = $_.Exception.Message;
    Write-Host "failed to connect to server: $errorMessage"
    Exit;
}


$server.RefreshSettings();


#------------------------------------------------------------
# attempt to force change password on first login for the site
# admin
#------------------------------------------------------------

$val = $server.ForceAdminResetPasswordOnInitialLogin
Write-Host "force change password was $val"

$server.ForceAdminResetPasswordOnInitialLogin = $bValue
$server.ApplyChanges()

$val = $server.ForceAdminResetPasswordOnInitialLogin
Write-Host "force change password is now $val"


#------------------------------------------------------------
# cleanup and exit
#------------------------------------------------------------

$server.Close();

[System.Runtime.Interopservices.Marshal]::ReleaseComObject($server) | out-null
Remove-Variable server

