<#
.SYNOPSIS
   Set the server-level log path
.DESCRIPTION
   Set the server-level log path
.PARAMETER eftAdminPort
   specify the EFT administrative port for COM connection -- default 1100
.PARAMETER eftAdminName
   name of the EFT administrative account
.PARAMETER eftAdminPassword
   password for the EFT administrative account
.PARAMETER auth method
   authentication method - 1 EFT local auth ; 2 Windows Auth

#>

param([int]$eftAdminPort=1100,
      [string]$eftAdminName = "admin",
      [string]$eftAdminPassword = "myAdmin123",
      [int]$authMethod = 1,
      [bool]$bValue = $True,
      [Parameter(Mandatory=$False)][string]$logPath
)


#------------------------------------------------------------
# login as admin
#------------------------------------------------------------

try {
    $server = New-Object -ComObject 'SFTPComInterface.CIServer'
    $server.ConnectEx( "localhost", $eftAdminPort, $authMethod, $eftAdminName, $eftAdminPassword );
    Write-Host "connected"
}
catch {
    $errorMessage = $_.Exception.Message;
    Write-Host "failed to connect to server: $errorMessage"
    Exit;
}


$server.RefreshSettings();


#------------------------------------------------------------
# set the log path
#------------------------------------------------------------

if($logPath) {
    $server.LogPath = $logPath
    $server.ApplyChanges()
}

$val = $server.LogPath
Write-Host "LogPath is $val"


#------------------------------------------------------------
# cleanup and exit
#------------------------------------------------------------

$server.Close();

[System.Runtime.Interopservices.Marshal]::ReleaseComObject($server) | out-null
Remove-Variable server

