'*****************************************************************************
' Copyright (C) 2016 GlobalSCAPE, Inc.
'
' The copyright to the computer program(s) herein is the property of
' GlobalSCAPE, Inc. The program(s) may be used and/or copied only with
' the written permission of  GlobalSCAPE, Inc. or in accordance with the
' terms and conditions stipulated in the agreement/contract under which
' the program(s) have been supplied.
'*****************************************************************************

'####################################################################################################
'##
'##   This script provides an interface to the CISite.EnableWorkspacesOAI property via COM and allows
'## the caller to set that property to a specified "true" or "false" value.
'##
'## Parameters:
'##    %0 = IP address, or name, of the machine that is hosting the EFT server.  (Required)
'##    %1 = Integer value for the server administrator listening port. (Required)
'##    %2 = Server administrator credentials user-name.  (Required)
'##    %3 = Server administrator credentials password.  (Required)
'##    %4 = Name of the EFT site on which to set the EnableWorkspacesOAI property value.
'##    %5 = Integer representation of the true/false value to be assied to the EnableWorkspacesOAI
'##         property.  A value of 1 or greater equates to "true", while all other values equate to 
'##         "false."  (Required)
'##
'####################################################################################################

Option Explicit

Dim g_boolEnableOutlookAddin
Dim g_intAdminPort
Dim g_objEFTServer
Dim g_objSite
Dim g_strAdminUserName
Dim g_strAdminPassword
Dim g_strHostNameOrIPAddr
Dim g_strSiteName

'**********************************************************************************************************************
'
'  SECTION: Statements that define the flow of execution for the script.
'
'**********************************************************************************************************************

' Assign the command-line arguments to global variables.
g_strHostNameOrIPAddr = WScript.Arguments.Item(0)
g_intAdminPort = WScript.Arguments.Item(1)
g_strAdminUserName = WScript.Arguments.Item(2)
g_strAdminPassword = WScript.Arguments.Item(3)
g_strSiteName = WScript.Arguments.Item(4)
If WScript.Arguments.Item(5) >= 1 Then
  g_boolEnableOutlookAddin = True
Else
  g_boolEnableOutlookAddin = False
End If

' Use COM to connect to EFT.
If Not InitializeEFTConnection(g_strHostNameOrIPAddr, g_intAdminPort, g_strAdminUserName, g_strAdminPassword) Then
  WScript.Quit(0)
End If

' Enable or disable the Workspaces Outlook Add-in for the specified site.
Set g_objSite = GetSite(g_strSiteName)
If Not g_objSite Is Nothing Then
  g_objSite.EnableWorkspacesOAI = g_boolEnableOutlookAddin
  Call g_objEFTServer.ApplyChanges
End If

' Close out script execution.
Call Cleanup()


'**********************************************************************************************************************
'
'  SECTION: Sub and Function procedure definitions.
'
'**********************************************************************************************************************

Sub CleanUp()
    If Not g_objEFTServer Is Nothing Then
      g_objEFTServer.Close()
      WScript.Sleep 1.0
      Set g_objEFTServer = Nothing
    End If
End Sub 'CleanUp


Function GetSite(strSiteName_p)
  Dim site, sites, i
  
  Set sites = g_objEFTServer.Sites()
  For i = 0 To sites.Count -1
    Set site = sites.Item(i)
    If site.Name = strSiteName_p Then
      Set GetSite = site
      Exit Function
    End If
  Next
  
  Set GetSite = Nothing
End Function 'GetSite

Function InitializeEFTConnection(strHostNameOrIPAddr_p, intPort_p, strAdminUserName_p, strPassword_p)
    Dim boolResult : boolResult = true

    On Error Resume Next
    Err.Clear
    Set g_objEFTServer = CreateObject("SFTPCOMInterface.CIServer")
    g_objEFTServer.Connect strHostNameOrIPAddr_p, intPort_p, strAdminUserName_p, strPassword_p
    If Err.Number <> 0 Then
        boolResult = false
        Set g_objEFTServer = Nothing
        WScript.Echo "Error " & Err.Number & " connecting to " & strHostNameOrIPAddr_p & ". " _
                     & Err.Description, vbInformation, "Error"
    End If

    InitializeEFTConnection = boolResult
End Function 'InitializeEFTConnection