﻿$serverIp = "localhost"
$serverPort = 1100

$EFTServer = New-Object -COM "SFTPCOMInterface.CIServer"
$EFTServer.ConnectEX($serverIP, $serverPort, 1, "","")
$siteCount = $EFTServer.Sites().Count()
$ErrorActionPreference = 'Stop'
$siteID = $null
$siteName = $null

$EFTWorkflow = New-Object -COM "SFTPCOMInterface.CIAdvancedWorkflowParams"
$EFTWorkflow.Name = "AWE-1"
$EFTWorkflow.Description = "Created through COM - This Workflow is a copy of Sample - Ping"
$EFTWorkflow.Code = 
" 
<AMTASK>
<AMTASKHEAD>
<TASKINFO TASKVERSION=`"10.7.100.1`" />
</AMTASKHEAD>

<AMFUNCTION NAME=`"Main`" ACCESS=`"private`" RETURNTYPE=`"variable`">
<!-- ---------- -->
<!-- GENERAL TASK NOTES:  This task will ping a machine dictated by its IP address, and then display a message about whether the machine is responding or 
not. -->
<!-- ---------- -->
<AMVARIABLE NAME=`"machineIP`" VALUE=`"google.com`" />
<AMVARIABLE NAME=`"responseTime`" VALUE=`"`" />
<AMVARIABLE NAME=`"noResponse`" VALUE=`"`" />
<AMSHOWDIALOG WINDOWTITLE=`"Machine Not Responding`">About to ping %machineIP%.  </AMSHOWDIALOG>
<AMNETWORK ACTIVITY=`"send`" AM_SETVAR=`"noResponse;1`" HOST=`"%machineIP%`" RESULTVARIABLE=`"responseTime`" AM_FAILACTION=`"4`" />
<AMIF EXPRESSION=`"%noResponse% = 1`">
<AMSHOWDIALOG WINDOWTITLE=`"Machine Not Responding`">%machineIP%, is not responding.</AMSHOWDIALOG>
<AMELSE />
<AMSHOWDIALOG WINDOWTITLE=`"Machine Not Responding`">%machineIP%, responded within

%responseTime% milliseconds.</AMSHOWDIALOG>
</AMIF>
</AMFUNCTION>

<AMFUNCTION NAME=`"OnStepStart`" ACCESS=`"private`">
<AMPARAMETER NAME=`"FunctionName`" DESCRIPTION=`"The function that is starting the step`" SUBTYPE=`"text`" />
<AMPARAMETER NAME=`"StepNumber`" DESCRIPTION=`"The step number that is about to execute`" SUBTYPE=`"number`" />

</AMFUNCTION>

<AMFUNCTION NAME=`"OnStepEnd`" ACCESS=`"private`">
<AMPARAMETER NAME=`"FunctionName`" DESCRIPTION=`"The function that is ending the step`" SUBTYPE=`"text`" />
<AMPARAMETER NAME=`"StepNumber`" DESCRIPTION=`"The step number that is about to end`" SUBTYPE=`"number`" />

</AMFUNCTION>

<AMFUNCTION NAME=`"OnStepError`" ACCESS=`"private`">
<AMPARAMETER NAME=`"FunctionName`" DESCRIPTION=`"The function with the error`" SUBTYPE=`"text`" />
<AMPARAMETER NAME=`"StepNumber`" DESCRIPTION=`"The step number of the error`" SUBTYPE=`"number`" />
<AMPARAMETER NAME=`"ErrorText`" DESCRIPTION=`"The text of the error`" SUBTYPE=`"text`" />
<AMPARAMETER NAME=`"ErrorCode`" DESCRIPTION=`"The code of the error`" SUBTYPE=`"number`" />

</AMFUNCTION>

<AMFUNCTION NAME=`"OnTaskFailure`" ACCESS=`"private`">
<AMPARAMETER NAME=`"FunctionName`" DESCRIPTION=`"The function causing the task failure`" SUBTYPE=`"text`" />
<AMPARAMETER NAME=`"StepNumber`" DESCRIPTION=`"The step number causing the task failure`" SUBTYPE=`"number`" />
<AMPARAMETER NAME=`"ErrorText`" DESCRIPTION=`"The text of the error`" SUBTYPE=`"text`" />
<AMPARAMETER NAME=`"ErrorCode`" DESCRIPTION=`"The code of the error`" SUBTYPE=`"number`" />

</AMFUNCTION>
                              
<AMFUNCTION NAME=`"OnTaskStart`" ACCESS=`"private`">
<AMPARAMETER NAME=`"Reason`" DESCRIPTION=`"The reason the task is starting`" SUBTYPE=`"text`" />

</AMFUNCTION>

<AMFUNCTION NAME=`"OnTaskEnd`" ACCESS=`"private`">
<AMPARAMETER NAME=`"Reason`" DESCRIPTION=`"The reason the task is ending`" SUBTYPE=`"text`" />

</AMFUNCTION>

</AMTASK>
" 

Write-Host "------------------------------------------------------------"
Write-Host "- This script creates Sample - Ping workflows named: " -NoNewline; Write-Host "AWE-#" -ForegroundColor Green -NoNewline; Write-Host " -"
Write-Host "------------------------------------------------------------" 
Write-Host ""
[string]$siteName = Read-Host -Prompt "Enter the name of the Site to configure or type --list to see availible sites"

while($siteName.Equals("--list"))
{
Write-Host ""
Write-Host "Sites"
Write-Host "-----"
for($j = 0; $j -lt $siteCount; $j++) #for loop to list availible sites
 {
Write-Host $EFTServer.Sites().Item($j).Name
 }
 Write-Host ""
[string]$siteName = Read-Host -Prompt "Enter the name of the Site to configure or type --list to see availible sites"
}

for($j = 0; $j -lt $siteCount; $j++) #for loop to find siteID
 {
  if ($EFTServer.Sites().Item($j).Name -eq $siteName)
  {
  $siteID = $EFTServer.Sites().Item($j).Id
  $siteName = $EFTServer.Sites().Item($j).Name
  }
 }

 if ($siteID -le 0)
  {
  Write-Host "Could no find site!"
  exit
  }

Write-Host ""
Write-Host $siteName -ForegroundColor Green -NoNewline 
[string]$howMany = Read-Host -Prompt " - How many to create?"

Try
{
for($j = 1; $j -le $howMany; $j++)
 {
$EFTWorkflow.Name = "AWE-$j"
$AWparams = $EFTServer.Sites().SiteByID($siteID).AddAdvancedWorkflow($EFTWorkflow) | Out-Null
} 
}

Catch
{
Write-Host "Error!" -NoNewline -ForegroundColor Red; Write-Host " - Make sure the site does not already have any AWE's named: " -NoNewline; Write-Host "AWE-#" -Foregroundcolor Green
$EFTServer.Close() | out-null
Remove-Variable * -ErrorAction SilentlyContinue
exit
}
Write-Host "Done!"
Sleep 2
$EFTServer.Close() | out-null
Remove-Variable * -ErrorAction SilentlyContinue